@@ -41,6 +41,9 @@ INTERNALERROR_DELETESERVICEERROR = 'InternalError.DeleteServiceError'
 # 版本部署调用失败。
 INTERNALERROR_DEPLOYVERSIONERROR = 'InternalError.DeployVersionError'
 
+# 查询 ingress 失败。
+INTERNALERROR_DESCRIBEINGRESSERROR = 'InternalError.DescribeIngressError'
+
 # 查询实例信息失败。
 INTERNALERROR_DESCRIBERUNPODLISTERROR = 'InternalError.DescribeRunPodListError'
 
@@ -53,6 +56,9 @@ INTERNALERROR_DESCRIBESERVICELISTERROR = 'InternalError.DescribeServiceListError
 # 重启失败。
 INTERNALERROR_RESTARTAPPLICATIONERROR = 'InternalError.RestartApplicationError'
 
+# 停止应用失败。
+INTERNALERROR_STOPAPPLICATIONERROR = 'InternalError.StopApplicationError'
+
 # 更新 ingress 失败。
 INTERNALERROR_UPDATEINGRESSERROR = 'InternalError.UpdateIngressError'
 
@@ -95,6 +101,9 @@ INVALIDPARAMETERVALUE_SERVICEPODREACHMAXIMUM = 'InvalidParameterValue.ServicePod
 # 应用创建失败，达到上限。
 INVALIDPARAMETERVALUE_SERVICEREACHMAXIMUM = 'InvalidParameterValue.ServiceReachMaximum'
 
+# 不是合法的TEM ID。
+INVALIDPARAMETERVALUE_TEMIDINVALID = 'InvalidParameterValue.TemIdInvalid'
+
 # 非 JAVA 应用不支持链路追踪特性。
 INVALIDPARAMETERVALUE_TRAITSTRACINGNOTSUPPORTED = 'InvalidParameterValue.TraitsTracingNotSupported'
 
@@ -119,6 +128,12 @@ MISSINGPARAMETER_SERVICEIDNULL = 'MissingParameter.ServiceIdNull'
 # 镜像仓库还未就绪。
 MISSINGPARAMETER_SVCREPONOTREADY = 'MissingParameter.SvcRepoNotReady'
 
+# 账户余额不足。
+OPERATIONDENIED_BALANCENOTENOUGH = 'OperationDenied.BalanceNotEnough'
+
+# 账号欠费状态下不支持该操作，请冲正后重试。
+OPERATIONDENIED_RESOURCEISOLATED = 'OperationDenied.ResourceIsolated'
+
 # 你操作的资源已被其他操作占用，请稍后重试。
 RESOURCEINUSE_RESOURCEALREADYLOCKED = 'ResourceInUse.ResourceAlreadyLocked'
 
